@@ -116,6 +116,16 @@ def valid_chart(chart_type=None, x=None, y=None, z=None, **inputs):
         chart_props = ["{}_value", "{}_label"]
         return all(inputs.get(p.format(chart_type)) is not None for p in chart_props)
 
+    if chart_type == "clustergram":
+        if (
+            inputs.get("clustergram_value") is None
+            or inputs.get("clustergram_label") is None
+        ):
+            return False
+        if len(make_list(inputs["clustergram_value"])) == 0:
+            return False
+        return True
+
     if not x:
         return False
 
@@ -906,6 +916,12 @@ def build_base_chart(
         "chart_data = chart_data.rename(columns={'" + x + "': '" + x_col + "'})"
     )
 
+    # convert booleans into integers for aggregation
+    for col in z_cols or y_cols:
+        classifier = classify_type(find_dtype(data[col]))
+        if classifier == "B":
+            data.loc[:, col] = data[col].astype("int")
+
     if agg is not None or len(extended_aggregation):
         data, agg_code, final_cols = build_agg_data(
             data,
@@ -919,6 +935,7 @@ def build_base_chart(
         )
         code += agg_code
     data = data.dropna()
+
     if return_raw:
         return data.rename(columns={x_col: x})
     code.append("chart_data = chart_data.dropna()")
