@@ -21,7 +21,7 @@ from strsimpy.jaro_winkler import JaroWinkler
 
 import dtale.global_state as global_state
 from dtale.translations import text
-from dtale.utils import classify_type, apply
+from dtale.utils import classify_type, apply, find_dtype_formatter
 
 
 class ColumnBuilder(object):
@@ -31,6 +31,10 @@ class ColumnBuilder(object):
             self.builder = NumericColumnBuilder(name, cfg)
         elif column_type == "string":
             self.builder = StringColumnBuilder(name, cfg)
+        elif column_type == "concatenate":
+            self.builder = ConcatenateColumnBuilder(name, cfg)
+        elif column_type == "replace":
+            self.builder = ReplaceColumnBuilder(name, cfg)
         elif column_type == "datetime":
             self.builder = DatetimeColumnBuilder(name, cfg)
         elif column_type == "bins":
@@ -61,6 +65,16 @@ class ColumnBuilder(object):
             self.builder = RollingBuilder(name, cfg)
         elif column_type == "exponential_smoothing":
             self.builder = ExponentialSmoothingBuilder(name, cfg)
+        elif column_type == "cumsum":
+            self.builder = CumsumColumnBuilder(name, cfg)
+        elif column_type == "shift":
+            self.builder = ShiftBuilder(name, cfg)
+        elif column_type == "expanding":
+            self.builder = ExpandingBuilder(name, cfg)
+        elif column_type == "substring":
+            self.builder = SubstringBuilder(name, cfg)
+        elif column_type == "split":
+            self.builder = SplitBuilder(name, cfg)
         else:
             raise NotImplementedError(
                 "'{}' column builder not implemented yet!".format(column_type)
@@ -133,6 +147,60 @@ class StringColumnBuilder(object):
         ).format(name=self.name, data_str=data_str)
 
 
+class ConcatenateColumnBuilder(object):
+    def __init__(self, name, cfg):
+        self.name = name
+        self.cfg = cfg
+
+    def build_column(self, data):
+        left, right = (self.cfg.get(p) for p in ["left", "right"])
+        left = data[left["col"]].astype("str") if "col" in left else left["val"]
+        right = data[right["col"]].astype("str") if "col" in right else right["val"]
+        return left + right
+
+    def build_code(self):
+        left, right = (self.cfg.get(p) for p in ["left", "right"])
+        return "df.loc[:, '{name}'] = {left} + {right}".format(
+            name=self.name,
+            left="df['{}'].astype('str')".format(left["col"])
+            if "col" in left
+            else left["val"],
+            right="df['{}'].astype('str')".format(right["col"])
+            if "col" in right
+            else right["val"],
+        )
+
+
+class ReplaceColumnBuilder(object):
+    def __init__(self, name, cfg):
+        self.name = name
+        self.cfg = cfg
+
+    def build_column(self, data):
+        col, search, replacement, case, regex = (
+            self.cfg.get(p)
+            for p in ["col", "search", "replacement", "caseSensitive", "regex"]
+        )
+        return pd.Series(
+            data[col].str.replace(search, replacement, case=case, regex=regex),
+            index=data.index,
+            name=self.name,
+        )
+
+    def build_code(self):
+        col, search, replacement, case, regex = (
+            self.cfg.get(p)
+            for p in ["col", "search", "replacement", "caseSensitive", "regex"]
+        )
+        return "data['{col}'].str.replace('{search}', '{replacement}', case={case}, regex={regex})".format(
+            col=col,
+            search=search,
+            replacement=replacement,
+            case="True" if case else "False",
+            regex="True" if regex else "False",
+        )
+
+
 FREQ_MAPPING = dict(month="M", quarter="Q", year="Y")
 
 
@@ -1056,7 +1124,7 @@ def clean(s, cleaner, cfg):
     elif cleaner == "hidden_chars":
         return s.str.replace(r"[^{}]+".format(printable), "")
     elif cleaner == "replace_hyphen_w_space":
-        return s.str.replace(r"[‐᠆﹣－⁃−-]+", " ")
+        return s.str.replace(r"[‐᠆﹣－⁃−\-]+", " ")
     return s
 
 
@@ -1312,3 +1380,135 @@ class ExponentialSmoothingBuilder(object):
                 name=self.name
             ),
         ]
+
+
+class CumsumColumnBuilder(object):
+    def __init__(self, name, cfg):
+        self.name = name
+        self.cfg = cfg
+
+    def build_column(self, data):
+        col = self.cfg.get("col")
+        group = self.cfg.get("group")
+        if group:
+            s = data.groupby(group)[col]
+        else:
+            s = data[col]
+        return pd.Series(s.cumsum(axis=0), index=data.index, name=self.name)
+
+    def build_code(self):
+        col = self.cfg.get("col")
+        group = self.cfg.get("group")
+        group_code = ""
+        if group:
+            group_code = ".groupby(['{}'])".format("','".join(group))
+        return (
+            "df.loc[:, '{name}'] = pd.Series(\n"
+            "\t(data{group}['{col}'].cumsum(axis=0), index=data.index, name='{name}'\n"
+            ")"
+        ).format(name=self.name, col=col, group=group_code)
+
+
+class ShiftBuilder(object):
+    def __init__(self, name, cfg):
+        self.name = name
+        self.cfg = cfg
+
+    def build_column(self, data):
+        col, periods, fill_value, dtype = (
+            self.cfg.get(p) for p in ["col", "periods", "fillValue", "dtype"]
+        )
+        kwargs = {}
+        if fill_value is not None:
+            fill_formatter = find_dtype_formatter(dtype)
+            kwargs["fill_value"] = fill_formatter(fill_value)
+        return pd.Series(
+            data[col].shift(periods or 1, **kwargs),
+            index=data.index,
+            name=self.name,
+        )
+
+    def build_code(self):
+        col, periods, fill_value, dtype = (
+            self.cfg.get(p) for p in ["col", "periods", "fillValue", "dtype"]
+        )
+        kwargs = ""
+        if fill_value is not None:
+            if classify_type(dtype) == "S":
+                kwargs = ", fill_value='{}'".format(fill_value)
+            else:
+                kwargs = ", fill_value={}".format(fill_value)
+        return (
+            "df.loc[:, '{name}'] = pd.Series(\n"
+            "\t(data['{col}'].shift({periods}{kwargs}), index=data.index, name='{name}'\n"
+            ")"
+        ).format(name=self.name, col=col, periods=periods, kwargs=kwargs)
+
+
+class ExpandingBuilder(object):
+    def __init__(self, name, cfg):
+        self.name = name
+        self.cfg = cfg
+
+    def build_column(self, data):
+        col, periods, agg = (self.cfg.get(p) for p in ["col", "periods", "agg"])
+        return pd.Series(
+            getattr(data[col].expanding(periods or 1), agg)(),
+            index=data.index,
+            name=self.name,
+        )
+
+    def build_code(self):
+        col, periods, agg = (self.cfg.get(p) for p in ["col", "periods", "agg"])
+        return (
+            "df.loc[:, '{name}'] = pd.Series(\n"
+            "\t(data['{col}'].expanding({periods}).{agg}(), index=data.index, name='{name}'\n"
+            ")"
+        ).format(name=self.name, col=col, periods=periods or 1, agg=agg)
+
+
+class SubstringBuilder(object):
+    def __init__(self, name, cfg):
+        self.name = name
+        self.cfg = cfg
+
+    def build_column(self, data):
+        col, start, end = (self.cfg.get(p) for p in ["col", "start", "end"])
+        start = int(start)
+        end = int(end)
+        s = data[col].str[:end] if start == 0 else data[col].str.slice(start, end)
+        return pd.Series(s, index=data.index, name=self.name)
+
+    def build_code(self):
+        col, start, end = (self.cfg.get(p) for p in ["col", "start", "end"])
+        if start == 0:
+            return (
+                "df.loc[:, '{name}'] = pd.Series(data['{col}'].str[:{end}], index=data.index, name='{name}')"
+            ).format(name=self.name, col=col, end=end)
+        return (
+            "df.loc[:, '{name}'] = pd.Series(\n"
+            "\t(data['{col}'].str.slice({start}, {end}), index=data.index, name='{name}'\n"
+            ")"
+        ).format(name=self.name, col=col, start=start, end=end)
+
+
+class SplitBuilder(object):
+    def __init__(self, name, cfg):
+        self.name = name
+        self.cfg = cfg
+
+    def build_column(self, data):
+        col, delimiter = (self.cfg.get(p) for p in ["col", "delimiter"])
+        splits = data[col].str.split(delimiter, expand=True)
+        splits.columns = ["{}_{}".format(self.name, col2) for col2 in splits.columns]
+        return splits
+
+    def build_code(self):
+        col, delimiter = (self.cfg.get(p) for p in ["col", "delimiter"])
+        return (
+            "splits = data['{col}'].str.split('{delimiter}'), expand=True)\n"
+            "splits.columns = ['{name}_' + col2 for col2 in splits.columns]\n"
+            "for i in range(len(splits.columns)):\n"
+            "\tnew_col = splits.iloc[:, i]\n"
+            "\tdf.loc[:, str(new_col.name)] = new_col"
+        ).format(col=col, delimiter=delimiter, name=self.name)
