@@ -76,6 +76,30 @@ def load_app_settings(config):
     main_title_font = get_config_val(
         config, curr_app_settings, "main_title_font", section="app"
     )
+    query_engine = get_config_val(
+        config, curr_app_settings, "query_engine", section="app"
+    )
+    open_custom_filter_on_startup = get_config_val(
+        config,
+        curr_app_settings,
+        "open_custom_filter_on_startup",
+        section="app",
+        getter="getboolean",
+    )
+    open_predefined_filters_on_startup = get_config_val(
+        config,
+        curr_app_settings,
+        "open_predefined_filters_on_startup",
+        section="app",
+        getter="getboolean",
+    )
+    hide_drop_rows = get_config_val(
+        config,
+        curr_app_settings,
+        "hide_drop_rows",
+        section="app",
+        getter="getboolean",
+    )
 
     global_state.set_app_settings(
         dict(
@@ -88,6 +112,10 @@ def load_app_settings(config):
             max_row_height=max_row_height,
             main_title=main_title,
             main_title_font=main_title_font,
+            query_engine=query_engine,
+            open_custom_filter_on_startup=open_custom_filter_on_startup,
+            open_predefined_filters_on_startup=open_predefined_filters_on_startup,
+            hide_drop_rows=hide_drop_rows,
         )
     )
 
@@ -147,6 +175,11 @@ def build_show_options(options=None):
         show_columns=None,
         hide_columns=None,
         column_formats=None,
+        nan_display=None,
+        sort=None,
+        locked=None,
+        background_mode=None,
+        range_highlights=None,
     )
     config_options = {}
     config = get_config()
@@ -204,6 +237,25 @@ def build_show_options(options=None):
             config_options["column_formats"] = json.loads(
                 config_options["column_formats"]
             )
+        config_options["nan_display"] = get_config_val(config, defaults, "nan_display")
+        config_options["sort"] = get_config_val(config, defaults, "sort")
+        if config_options["sort"]:
+            config_options["sort"] = [
+                tuple(sort.split("|")) for sort in config_options["sort"].split(",")
+            ]
+        config_options["locked"] = get_config_val(config, defaults, "locked")
+        if config_options["locked"]:
+            config_options["locked"] = config_options["locked"].split(",")
+        config_options["background_mode"] = get_config_val(
+            config, defaults, "background_mode"
+        )
+        config_options["range_highlights"] = get_config_val(
+            config, defaults, "range_highlights"
+        )
+        if config_options["range_highlights"]:
+            config_options["range_highlights"] = json.loads(
+                config_options["range_highlights"]
+            )
 
     return dict_merge(defaults, config_options, options)
 
