@@ -2,11 +2,10 @@ import json as json
 from logging import getLogger
 
 import dash
-import dash_core_components as dcc
-import dash_html_components as html
 from dash.dependencies import Input, Output, State
 from dash.exceptions import PreventUpdate
 
+from dtale.dash_application import dcc, html
 import dtale.dash_application.custom_geojson as custom_geojson
 import dtale.dash_application.drilldown_modal as drilldown_modal
 import dtale.dash_application.extended_aggregations as extended_aggregations
@@ -205,6 +204,7 @@ def init_callbacks(dash_app):
             Output("candlestick-inputs", "style"),
             Output("treemap-inputs", "style"),
             Output("funnel-inputs", "style"),
+            Output("clustergram-inputs", "style"),
             Output("colorscale-input", "style"),
             Output("drilldown-input", "style"),
             Output("lock-zoom-btn", "style"),
@@ -312,9 +312,11 @@ def init_callbacks(dash_app):
         treemap_style = {} if show_treemap else {"display": "none"}
         show_funnel = chart_type == "funnel"
         funnel_style = {} if show_funnel else {"display": "none"}
+        show_clustergram = chart_type == "clustergram"
+        clustergram_style = {} if show_clustergram else {"display": "none"}
         standard_style = (
             {"display": "none"}
-            if show_map or show_cs or show_treemap or show_funnel
+            if show_map or show_cs or show_treemap or show_funnel or show_clustergram
             else {}
         )
         cscale_style = colorscale_input_style(chart_type=chart_type)
@@ -333,6 +335,7 @@ def init_callbacks(dash_app):
             cs_style,
             treemap_style,
             funnel_style,
+            clustergram_style,
             cscale_style,
             drilldown_toggle_style,
             lock_zoom_style(chart_type),
@@ -351,7 +354,7 @@ def init_callbacks(dash_app):
             Output("group-dropdown", "value"),
             Output("query-input", "value"),
         ],
-        Input("data-tabs", "value"),
+        [Input("data-tabs", "value")],
         State("input-data", "data"),
     )
     def update_data_selection(data_id, input_data):
@@ -564,6 +567,7 @@ def init_callbacks(dash_app):
                 df,
                 selected_value=selected_value,
                 selected_label=selected_label,
+                all_value=prop == "clustergram",
             )
             return label_value_data, value_options, label_options
 
@@ -580,6 +584,16 @@ def init_callbacks(dash_app):
             show_style(len(make_list(group)) > 0),
         )
 
+    def clustergram_callback(selected_value, selected_label, group, data_id):
+        label_value_data, value_options, label_options = label_value_callback(
+            "clustergram"
+        )(selected_value, selected_label, group, data_id)
+        return (
+            label_value_data,
+            value_options,
+            label_options,
+        )
+
     dash_app.callback(
         [
             Output("treemap-input-data", "data"),
@@ -610,6 +624,20 @@ def init_callbacks(dash_app):
         [State("data-tabs", "value")],
     )(funnel_callback)
 
+    dash_app.callback(
+        [
+            Output("clustergram-input-data", "data"),
+            Output("clustergram-value-dropdown", "options"),
+            Output("clustergram-label-dropdown", "options"),
+        ],
+        [
+            Input("clustergram-value-dropdown", "value"),
+            Input("clustergram-label-dropdown", "value"),
+            Input("clustergram-group-dropdown", "value"),
+        ],
+        [State("data-tabs", "value")],
+    )(clustergram_callback)
+
     @dash_app.callback(
         [
             Output("y-multi-input", "style"),
@@ -778,6 +806,7 @@ def init_callbacks(dash_app):
             Input("candlestick-input-data", "modified_timestamp"),
             Input("treemap-input-data", "modified_timestamp"),
             Input("funnel-input-data", "modified_timestamp"),
+            Input("clustergram-input-data", "modified_timestamp"),
             Input("extended-aggregations", "modified_timestamp"),
             Input("load-btn", "n_clicks"),
         ],
@@ -789,6 +818,7 @@ def init_callbacks(dash_app):
             State("candlestick-input-data", "data"),
             State("treemap-input-data", "data"),
             State("funnel-input-data", "data"),
+            State("clustergram-input-data", "data"),
             State("last-chart-input-data", "data"),
             State("auto-load-toggle", "on"),
             State("load-clicks", "data"),
@@ -804,6 +834,7 @@ def init_callbacks(dash_app):
         _ts6,
         _ts7,
         _ts8,
+        _ts9,
         load_clicks,
         inputs,
         chart_inputs,
@@ -812,6 +843,7 @@ def init_callbacks(dash_app):
         cs_data,
         treemap_data,
         funnel_data,
+        clustergram_data,
         last_chart_inputs,
         auto_load,
         prev_load_clicks,
@@ -828,6 +860,7 @@ def init_callbacks(dash_app):
             cs_data,
             treemap_data,
             funnel_data,
+            clustergram_data,
             dict(extended_aggregation=ext_aggs or [])
             if inputs.get("chart_type") not in NON_EXT_AGGREGATION
             else {},
@@ -1037,6 +1070,7 @@ def init_callbacks(dash_app):
             Input("candlestick-input-data", "modified_timestamp"),
             Input("treemap-input-data", "modified_timestamp"),
             Input("funnel-input-data", "modified_timestamp"),
+            Input("clustergram-input-data", "modified_timestamp"),
         ],
         [
             State("input-data", "data"),
@@ -1044,6 +1078,7 @@ def init_callbacks(dash_app):
             State("candlestick-input-data", "data"),
             State("treemap-input-data", "data"),
             State("funnel-input-data", "data"),
+            State("clustergram-input-data", "data"),
         ],
     )
     def main_input_class(
@@ -1052,14 +1087,23 @@ def init_callbacks(dash_app):
         _ts3,
         _ts4,
         _ts5,
+        _ts6,
         inputs,
         map_inputs,
         cs_inputs,
         treemap_inputs,
         funnel_inputs,
+        clustergram_inputs,
     ):
         return main_inputs_and_group_val_display(
-            dict_merge(inputs, map_inputs, cs_inputs, treemap_inputs, funnel_inputs)
+            dict_merge(
+                inputs,
+                map_inputs,
+                cs_inputs,
+                treemap_inputs,
+                funnel_inputs,
+                clustergram_inputs,
+            )
         )
 
     @dash_app.callback(
@@ -1074,6 +1118,7 @@ def init_callbacks(dash_app):
             Input("candlestick-group-dropdown", "value"),
             Input("treemap-group-dropdown", "value"),
             Input("funnel-group-dropdown", "value"),
+            Input("clustergram-group-dropdown", "value"),
         ],
         [
             State("input-data", "data"),
@@ -1087,6 +1132,7 @@ def init_callbacks(dash_app):
         cs_group_cols,
         treemap_group_cols,
         funnel_group_cols,
+        clustergram_group_cols,
         inputs,
         prev_group_vals,
     ):
@@ -1100,6 +1146,8 @@ def init_callbacks(dash_app):
             group_cols = treemap_group_cols
         elif chart_type == "funnel":
             group_cols = funnel_group_cols
+        elif chart_type == "clustergram":
+            group_cols = clustergram_group_cols
         group_cols = make_list(group_cols)
         group_types = get_group_types(inputs, group_cols)
         if "groups" not in group_types:
