@@ -14,6 +14,7 @@ from flask import jsonify as _jsonify
 
 import numpy as np
 import pandas as pd
+from pkg_resources import parse_version
 from past.utils import old_div
 from six import StringIO
 
@@ -498,10 +499,18 @@ def get_dtypes(df):
 def coord_type(s):
     if classify_type(find_dtype(s)) not in ["F", "I"]:
         return None
+    is_pandas_1_3 = parse_version(pd.__version__) >= parse_version("1.3.0")
+    inclusive = "both" if is_pandas_1_3 else True
     if "lat" in s.name.lower():
-        return None if (~s.dropna().between(-90, 90, inclusive=True)).sum() else "lat"
+        return (
+            None if (~s.dropna().between(-90, 90, inclusive=inclusive)).sum() else "lat"
+        )
     if "lon" in s.name.lower():
-        return None if (~s.dropna().between(-180, 180, inclusive=True)).sum() else "lon"
+        return (
+            None
+            if (~s.dropna().between(-180, 180, inclusive=inclusive)).sum()
+            else "lon"
+        )
     return None
 
 
@@ -547,7 +556,7 @@ def grid_formatter(col_types, nan_display="", overrides=None, as_string=False):
     return f
 
 
-def format_grid(df):
+def format_grid(df, overrides=None):
     """
     Translate :class:`pandas:pandas.DataFrame` to well-formed JSON.  Structure is as follows:
     {
@@ -568,7 +577,7 @@ def format_grid(df):
     :return: JSON
     """
     col_types = grid_columns(df)
-    f = grid_formatter(col_types)
+    f = grid_formatter(col_types, overrides=overrides)
     return {"results": f.format_dicts(df.itertuples()), "columns": col_types}
 
 
